@@ -32,7 +32,7 @@ Defaults to 1; whether or not a nick can hide themselves from seen status.
 
 =head1 AUTHOR
 
-Tom Insam <tom@jerakeen.org>
+Mario Domgoergen <mdom@cpan.org>
 
 This program is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
