@@ -43,7 +43,7 @@ In this way we don't break any existing code.
 
 =head1 AUTHOR
 
-Mario Domgoergen <mario@domgoergen.com>
+Mario Domgoergen <mdom@cpan.org>
 
 This program is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
